@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Zircon/lib/RCS/Channel.tcl,v $
-# $Date: 1998/11/16 14:10:50 $
-# $Revision: 1.18.1.180 $
+# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Channel.tcl,v $
+# $Date: 1998/12/03 17:06:54 $
+# $Revision: 1.18.1.182 $
 #
 #
 package provide zircon 1.18
@@ -1457,9 +1457,9 @@ proc cpriv2 {op spk op1 spk1} {
     return 1
 }
 #
-proc sc {a b} { switch -- $a $b {return 1} ; return 0}
+proc sc {a b} { return [string compare $a $b]}
 #
-proc scl {a b} { switch -- $a [string tolower $b] {return 1} ; return 0 }
+proc sc1 {a b} { return [string compare $a [string tolower $b]] }
 #
 proc sortIns {chan nk usr w} {
     set last [$w index last]
@@ -1469,10 +1469,10 @@ proc sortIns {chan nk usr w} {
 	set spk [$chan isSpeaker $usr]
 	if {[$chan nocase]} {
 	    set cnk [string tolower $nk]
-	    set fn sc
+	    set fn sc1
 	} {
 	    set cnk $nk
-	    set fn scl
+	    set fn sc
 	}
 	if {[$chan nopriv]} {
 	    set fn1 nop
