@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/IRC.tcl,v $
-# $Date: 1998/07/21 12:59:25 $
-# $Revision: 1.18.1.55 $
+# $Date: 1998/09/02 12:02:34 $
+# $Revision: 1.18.1.59 $
 #
 package provide zircon 1.18
 #
@@ -112,17 +112,20 @@ proc ircMODE {net prefix param pargs} {
 }
 #
 proc doPatterns {where prefix param} {
+    regsub {^:} $prefix {} prefix
     foreach p [$where patterns] {
 	set pt [lindex $p 0]
 	if {[regexp -nocase [lindex $pt 0] $prefix] && \
 	  [regexp [lindex $pt 1] $param]} {
 	    uplevel #0 set 0 [list $prefix]
 	    uplevel #0 set 1 [list [$where name]]
+	    uplevel #0 set 2 [list $param]
+	    uplevel #0 set net [$where net]
 	    if {[catch {uplevel #0 [lindex $p 1]} msg]} {
 		tellError {} {Pattern Command Error} \
 		  "Error when executing [$where name] pattern command \"[lindex $p 1]\" : $msg"
 	    }
-	    uplevel #0 unset 0 1
+	    uplevel #0 safeUnset 0 1 2 net
 	}
     }
 }
@@ -145,7 +148,8 @@ proc ircPRIVMSG {net prefix param pargs} {
 	if {[ignoreSet $ign msgs] || [ignoreSet $ign notes]} return
 	switch nil [set where [Message :: find $nk $net]] {
 	    global zircon
-	    if {[$net busy]} {
+	    set mmx [$net msgmax]
+	    if {($mmx > 0 && $mmx < [llength [$net messages]]) || [$net busy]} {
 		$net queue "NOTICE $nk :[$net busymsg]"
 		$net inform "Message from $nk at [getDate] : $param"
 	    } {
