@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/catless/Zircon/lib/RCS/List.tcl,v $
-# $Date: 1998/07/24 15:10:23 $
-# $Revision: 1.18.1.12 $
+# $Source: /home/nlfm/Zircon/lib/RCS/List.tcl,v $
+# $Date: 1998/11/13 12:21:42 $
+# $Revision: 1.18.1.13 $
 #
 package provide zircon 1.18
 #
@@ -306,5 +306,5 @@ proc list_process {this} {
       filter.maxm filter.minm btn.list} {
 	catch {$w.$x configure -state normal}
     }
-    allowSBs $net $w
+    catch {allowSBs $net $w}
 }
