@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Zircon/lib/RCS/Util.tcl,v $
-# $Date: 1998/11/06 10:07:39 $
-# $Revision: 1.18.1.80 $
+# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Util.tcl,v $
+# $Date: 1998/12/03 17:07:01 $
+# $Revision: 1.18.1.81 $
 #
 package provide zircon 1.18
 #
@@ -295,7 +295,7 @@ proc getDate {} { return [clock format [clock seconds]] }
 #
 proc ipPack {ip} {
     set val 0
-    foreach x [split $ip .] { set val [expr {($val << 8) | ($x & 0377)}] }
+    foreach x [split $ip .] { set val [expr {($val << 8) | ($x & 0xff)}] }
     return [format %u $val]
 }
 #
