@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/confTab.tcl,v $
-# $Date: 1998/11/16 14:11:03 $
-# $Revision: 1.18.1.18 $
+# $Date: 1998/11/23 10:32:36 $
+# $Revision: 1.18.1.19 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -109,11 +109,19 @@ proc confrevclean {net which} {
     Channels {
 	    global newChn delChn
 	    foreach v $newChn($net) {
-	    if {![$v sys]} { $v delete }
+	        if {![$v sys]} { $v delete }
 	    }
 	    Channel :: cleanup $net new
 	    unset newChn($net) delChn($net)
         }
+    Messages {
+	    global newMsg delMsg
+	    foreach v $newMsg($net) {
+	        if {![$v sys]} { $v delete }
+	    }
+	    Message :: cleanup $net new
+	    unset newMsg($net) delMsg($net)
+        }
 
     Friends {
 	    global newFrd delFrd
