@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/initial.tcl,v $
-# $Date: 1998/09/23 11:30:01 $
-# $Revision: 1.18.1.177 $
+# $Date: 1998/11/13 12:21:51 $
+# $Revision: 1.18.1.178 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -375,7 +375,7 @@ Continue?}]} {
     set opts {}
     foreach arg $argv {
 	if {[string match {-*} $arg]} {
-	    foreach bit [split [string range $arg 1 end]] {
+	    foreach bit [split [string range $arg 1 end] {}] {
 		switch $bit {
 		C - j - o - z { set zircon($bit) 1 }
 		d - r - i - l - N - S - p { lappend opts $bit}
@@ -389,6 +389,7 @@ Continue?}]} {
 	    switch $opt {
 	    i - N - S - r - p { set zircon($opt) $arg }
 	    l { set zircon(language) $arg }
+	    d { set zircon(prefdir) $arg }
 	    default { }
 	    }
 	}
