@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/main.tcl,v $
-# $Date: 1998/11/19 16:18:30 $
-# $Revision: 1.18.1.88 $
+# $Date: 1998/11/23 10:32:40 $
+# $Revision: 1.18.1.89 $
 #
 package provide zircon 1.18
 #
@@ -133,15 +133,14 @@ proc irc001 {net prefix param pargs} {
     }
     $net inform $param
     $net setupTests
+    if {![$net noRefresh]} { $this channelList { } }
     handleOn $net STARTUP [list [$srv host] [$srv port]]
 }
 #
 proc irc004 {net prefix param pargs} {
-zshow $pargs
     set srvmsg 1
     switch -regexp -- [set vers [lindex $pargs 2]] {
     {^(2\.9|2.[1-9][0-9]+|[3-9]).*} {
-zshow $vers
     	    set srvmsg 0
 	}
      u.* {
